@@ -1,7 +1,9 @@
+from .exports import get_exports
+from .imports import get_imports
 from .repair import copylib, repair, repair_extracted, resolve_sharedlib
 from .show import show, show_dylib, show_wheel
 
-__version__ = "0.0.5"
+__version__ = "0.0.7"
 __all__ = [
     "repair",
     "repair_extracted",
@@ -10,4 +12,6 @@ __all__ = [
     "show_wheel",
     "show_dylib",
     "copylib",
+    "get_exports",
+    "get_imports",
 ]
